ThemeManager class

Constructors

ThemeManager()
factory

Properties

authService → AuthService
no setter
configService → ConfigService
no setter
core ↔ LittleFishCore
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icons → LittleFishIcons
no setter
isInitialised bool
no setter
isReady bool
no setter
logger → LoggerService
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings → ThemeSettings
no setter
themingService → LittleFishThemingService
no setter

Methods

getAppTheme() Future<ThemeData>
getBrandAsset(AssetType assetType) Future<String>
getDefaultConfig(String usecase) Map<String, dynamic>
initialise({String defaultConfigUseCase = '', bool loadFromConfigService = true}) Future<ThemeSettings>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ThemeManager
final